package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.RecordLeave;

/**
 * 请假记录信息Service接口
 * 
 * @author boman
 * @date 2023-08-08
 */
public interface IRecordLeaveService 
{
    /**
     * 查询请假记录信息
     * 
     * @param id 请假记录信息主键
     * @return 请假记录信息
     */
    public RecordLeave selectRecordLeaveById(Long id);

    /**
     * 查询请假记录信息列表
     * 
     * @param recordLeave 请假记录信息
     * @return 请假记录信息集合
     */
    public List<RecordLeave> selectRecordLeaveList(RecordLeave recordLeave);

    /**
     * app请假记录数量通知
     * @param recordLeave
     * @return
     */
    public AjaxResult selectRecordLeaveNum(RecordLeave recordLeave);

    /**
     * 新增请假记录信息
     * 
     * @param recordLeave 请假记录信息
     * @return 结果
     */
    public int insertRecordLeave(RecordLeave recordLeave);

    /**
     * 修改请假记录信息
     * 
     * @param recordLeave 请假记录信息
     * @return 结果
     */
    public int updateRecordLeave(RecordLeave recordLeave);

    /**
     * 批量删除请假记录信息
     * 
     * @param ids 需要删除的请假记录信息主键集合
     * @return 结果
     */
    public int deleteRecordLeaveByIds(Long[] ids);

    /**
     * 删除请假记录信息信息
     * 
     * @param id 请假记录信息主键
     * @return 结果
     */
    public int deleteRecordLeaveById(Long id);
}
